projectal.entities.skill API documentation

# projectal.entities.skill

View Source

     1from projectal.entity import Entity
     2from projectal.linkers import *
     3
     4
     5class Skill(Entity, StaffLinker, TaskLinker, TaskTemplateLinker, TagLinker):
     6    """
     7    Implementation of the [Skill](https://projectal.com/docs/latest/#tag/Skill) API.
     8    """
     9    _path = 'skill'
    10    _name = 'skill'
    11    _links = [TagLinker]  # TODO: note?
    12    _links_reverse = [StaffLinker, TaskLinker, TaskTemplateLinker]

class Skill(projectal.entity.Entity, projectal.linkers.StaffLinker, projectal.linkers.TaskLinker, projectal.linkers.TaskTemplateLinker, projectal.linkers.TagLinker): View Source

     6class Skill(Entity, StaffLinker, TaskLinker, TaskTemplateLinker, TagLinker):
     7    """
     8    Implementation of the [Skill](https://projectal.com/docs/latest/#tag/Skill) API.
     9    """
    10    _path = 'skill'
    11    _name = 'skill'
    12    _links = [TagLinker]  # TODO: note?
    13    _links_reverse = [StaffLinker, TaskLinker, TaskTemplateLinker]

Implementation of the Skill API.

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
projectal.linkers.StaffLinker
  link_staff
  relink_staff
  unlink_staff
projectal.linkers.TaskLinker
  link_task
  unlink_task
projectal.linkers.TaskTemplateLinker
  link_task_template
  unlink_task_template
projectal.linkers.TagLinker
  link_tag
  unlink_tag
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy